@@ -27,6 +27,7 @@
 #include <QtCore/QSharedPointer>
 #include <QtCore/QUrl>
 #include <QtNetwork/QNetworkAccessManager>
+#include <QtNetwork/QNetworkRequest>
 
 #include "atticaclient_export.h"
 #include "metadata.h"
@@ -45,6 +46,11 @@ public:
 
     Metadata metadata() const;
 
+    enum NetworkRequestCustomAttributes {
+        UserAttribute = QNetworkRequest::User + 1,
+        PasswordAttribute
+    };
+
 public Q_SLOTS:
     void start();
     void abort();
@@ -68,6 +74,7 @@ protected:
 
 private Q_SLOTS:
     void doWork();
+    void authenticationRequired(QNetworkReply*, QAuthenticator*);
 
 private:
     BaseJob(const BaseJob& other);
