@@ -21,8 +21,8 @@
 
 */
 
-#ifndef ATTICA_BUILDSERVICESOBOUTPUTPARSER_H
-#define ATTICA_BUILDSERVICESOBOUTPUTPARSER_H
+#ifndef ATTICA_BUILDSERVICEJOBOUTPUTPARSER_H
+#define ATTICA_BUILDSERVICEJOBOUTPUTPARSER_H
 
 #include "buildservicejoboutput.h"
 #include "parser.h"
@@ -39,4 +39,4 @@ public:
 
 } // namespace Attica
 
-#endif // ATTICA_BUILDSERVICESOBOUTPUTPARSER_H
+#endif // ATTICA_BUILDSERVICEJOBOUTPUTPARSER_H
