@@ -34,12 +34,12 @@ Category Category::Parser::parseXml(QXmlStreamReader& xml)
         xml.readNext();
 
         if (xml.isStartElement()) {
-            if (xml.name() == "id") {
+            if (xml.name() == QLatin1String("id")) {
                 category.setId(xml.readElementText());
-            } else if (xml.name() == "name") {
+            } else if (xml.name() == QLatin1String("name")) {
                 category.setName(xml.readElementText());
             }
-        } else if (xml.isEndElement() && xml.name() == "category") {
+        } else if (xml.isEndElement() && xml.name() == QLatin1String("category")) {
             break;
         }
     }
